@@ -25,5 +25,5 @@ import sys
 
 from . import cli
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     sys.exit(cli.main(__package__))
